package it.gulch.ld2012.accelerometertest;

import java.util.List;

import android.app.Activity;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.widget.Toast;

public class MainActivity extends Activity implements SensorEventListener
{
	private static final String TAG = MainActivity.class.getSimpleName();

	private SensorManager sensorManager;

	private Sensor accelerometer;

	private long lastUpdate = -1;

	private float last_z;

	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);

		sensorManager = (SensorManager) getSystemService(SENSOR_SERVICE);

		// Ottengo dal sensorManager la lista dei sensori di tipo accelerometro
		List<Sensor> sensorList = sensorManager.getSensorList(Sensor.TYPE_ACCELEROMETER);
		if(sensorList.size() > 0) {
			// tengo una istanza del sensore
			accelerometer = sensorList.get(0);

			// registro la classe corrente come listener degli eventi del
			// sensore
			// N.B.: la classe implementa l'interfaccia SensorEventListener
			sensorManager.registerListener(this, accelerometer, SensorManager.SENSOR_DELAY_NORMAL);
		} else {
			Toast.makeText(this, "Accelerometro non disponibile su questo dispositivo!", Toast.LENGTH_LONG).show();
		}
	}

	@Override
	protected void onDestroy()
	{
		super.onDestroy();

		sensorManager.unregisterListener(this);
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu)
	{
		getMenuInflater().inflate(R.menu.activity_main, menu);
		return true;
	}

	@Override
	public void onAccuracyChanged(Sensor sensor, int accuracy)
	{
	}

	// Quando il sensore lancia un evento, viene chiamata questa funzione
	@Override
	public void onSensorChanged(SensorEvent event)
	{
		// Verifico il tipo di evento ricevuto
		if(event.sensor.getType() != Sensor.TYPE_ACCELEROMETER) {
			return;
		}

		long curTime = System.currentTimeMillis();

		if((curTime - lastUpdate) > 100) {
			lastUpdate = curTime;

			// Verifico l'asse z della chiamata precedente con quello attuale
			float z = event.values[2];
			if((last_z >= 0) && (z < 0)) {
				// il dispositivo è stato girato a faccia in giù
				phoneFlippedDown();
			} else if((last_z < 0) && (z >= 0)) {
				// il dispositivo è stato girato a faccia in su
				phoneFlippedUp();
			}

			last_z = z;
		}
	}

	private void phoneFlippedUp()
	{
		// il dispositivo è stato girato a faccia in su
		Log.d(TAG, "phoneFlippedUp");
	}

	private void phoneFlippedDown()
	{
		// il dispositivo è stato girato a faccia in giù
		Log.d(TAG, "phoneFlippedDown");
	}
}
